@@ -2,6 +2,6 @@
 Hook used by pyinstaller to expose hidden imports.
 """
 
-from keyring.py310compat import metadata
+from keyring.compat.py312 import metadata
 
 hiddenimports = [ep.value for ep in metadata.entry_points(group='keyring.backends')]
