@@ -1,12 +1,21 @@
-import sys
-import platform
 import multiprocessing
+import platform
 
 import pytest
 
 import keyring
 
 
+@pytest.fixture(autouse=True)
+def workaround_pytest_12178(monkeypatch):
+    """
+    Ensure the current directory is on sys.path so that `tests` is importable.
+
+    Workaround for #673.
+    """
+    monkeypatch.syspath_prepend('.')
+
+
 def subprocess_get():
     keyring.get_password('test_app', 'test_user')
 
@@ -26,11 +35,6 @@ def test_multiprocess_get():
     assert proc1.exitcode == 0
 
 
-@pytest.mark.skipif(
-    # always skip as it crashes the interpreter
-    sys.version_info < (3, 8) and platform.system() == 'Darwin',
-    reason="#281: Prior to 3.8, multiprocess invocation fails",
-)
 def test_multiprocess_get_after_native_get():
     keyring.get_password('test_app', 'test_user')
     test_multiprocess_get()
